@@ -1,25 +1,24 @@
 import pytest
 from packaging.specifiers import SpecifierSet
 
+from asdf import config_context
+from asdf.exceptions import AsdfDeprecationWarning
 from asdf.extension import (
-    Extension,
-    ExtensionProxy,
-    ManifestExtension,
-    ExtensionManager,
-    get_cached_extension_manager,
-    TagDefinition,
-    Converter,
-    ConverterProxy,
-    Compressor,
     AsdfExtension,
     BuiltinExtension,
-    get_cached_asdf_extension_list
+    Compressor,
+    Converter,
+    ConverterProxy,
+    Extension,
+    ExtensionManager,
+    ExtensionProxy,
+    ManifestExtension,
+    TagDefinition,
+    get_cached_asdf_extension_list,
+    get_cached_extension_manager,
 )
-
-from asdf import config_context
-from asdf.types import CustomType
-
 from asdf.tests.helpers import assert_extension_correctness
+from asdf.types import CustomType
 
 
 def test_builtin_extension():
@@ -119,11 +118,12 @@ class FullConverter(MinimumConverter):
 
 class MinimalCompressor(Compressor):
     def compress(data):
-        return b''
+        return b""
 
     @property
     def label(self):
-        return b'mini'
+        return b"mini"
+
 
 # Some dummy types for testing converters:
 class FooType:
@@ -178,6 +178,7 @@ def test_extension_proxy():
     assert subclassed_proxy.legacy_class_names == proxy.legacy_class_names
     assert subclassed_proxy.asdf_standard_requirement == proxy.asdf_standard_requirement
     assert subclassed_proxy.converters == proxy.converters
+    assert subclassed_proxy.compressors == proxy.compressors
     assert subclassed_proxy.tags == proxy.tags
     assert subclassed_proxy.types == proxy.types
     assert subclassed_proxy.tag_mapping == proxy.tag_mapping
@@ -189,18 +190,14 @@ def test_extension_proxy():
     assert subclassed_proxy.class_name == "asdf.tests.test_extension.MinimumExtensionSubclassed"
 
     # Test with all properties present:
-    converters = [
-        MinimumConverter(
-            tags=["asdf://somewhere.org/extensions/full/tags/foo-*"],
-            types=[]
-        )
-    ]
+    converters = [MinimumConverter(tags=["asdf://somewhere.org/extensions/full/tags/foo-*"], types=[])]
+    compressors = [MinimalCompressor()]
     extension = FullExtension(
         converters=converters,
-        compressors=[MinimalCompressor],
+        compressors=compressors,
         asdf_standard_requirement=">=1.4.0",
         tags=["asdf://somewhere.org/extensions/full/tags/foo-1.0"],
-        legacy_class_names=["foo.extensions.SomeOldExtensionClass"]
+        legacy_class_names=["foo.extensions.SomeOldExtensionClass"],
     )
     proxy = ExtensionProxy(extension, package_name="foo", package_version="1.2.3")
 
@@ -208,7 +205,7 @@ def test_extension_proxy():
     assert proxy.legacy_class_names == {"foo.extensions.SomeOldExtensionClass"}
     assert proxy.asdf_standard_requirement == SpecifierSet(">=1.4.0")
     assert proxy.converters == [ConverterProxy(c, proxy) for c in converters]
-    assert proxy.compressors == [MinimalCompressor]
+    assert proxy.compressors == compressors
     assert len(proxy.tags) == 1
     assert proxy.tags[0].tag_uri == "asdf://somewhere.org/extensions/full/tags/foo-1.0"
     assert proxy.types == []
@@ -256,17 +253,17 @@ def test_extension_proxy_tags():
     foo_tag_uri = "asdf://somewhere.org/extensions/full/tags/foo-1.0"
     foo_tag_def = TagDefinition(
         foo_tag_uri,
-        schema_uri="asdf://somewhere.org/extensions/full/schemas/foo-1.0",
+        schema_uris="asdf://somewhere.org/extensions/full/schemas/foo-1.0",
         title="Some tag title",
-        description="Some tag description"
+        description="Some tag description",
     )
 
     bar_tag_uri = "asdf://somewhere.org/extensions/full/tags/bar-1.0"
     bar_tag_def = TagDefinition(
         bar_tag_uri,
-        schema_uri="asdf://somewhere.org/extensions/full/schemas/bar-1.0",
+        schema_uris="asdf://somewhere.org/extensions/full/schemas/bar-1.0",
         title="Some other tag title",
-        description="Some other tag description"
+        description="Some other tag description",
     )
 
     # The converter should return only the tags
@@ -353,11 +350,9 @@ def test_extension_manager():
         tags=[
             "asdf://somewhere.org/extensions/full/tags/baz-*",
         ],
-        types=[
-            BazType
-        ],
+        types=[BazType],
     )
-    converter3= FullConverter(
+    converter3 = FullConverter(
         tags=[
             "asdf://somewhere.org/extensions/full/tags/foo-*",
         ],
@@ -371,13 +366,13 @@ def test_extension_manager():
         tags=[
             "asdf://somewhere.org/extensions/full/tags/foo-1.0",
             "asdf://somewhere.org/extensions/full/tags/baz-1.0",
-        ]
+        ],
     )
     extension2 = FullExtension(
         converters=[converter3],
-        tags = [
+        tags=[
             "asdf://somewhere.org/extensions/full/tags/foo-1.0",
-        ]
+        ],
     )
 
     manager = ExtensionManager([extension1, extension2])
@@ -394,8 +389,14 @@ def test_extension_manager():
     assert manager.handles_type(BarType) is True
     assert manager.handles_type(BazType) is True
 
-    assert manager.get_tag_definition("asdf://somewhere.org/extensions/full/tags/foo-1.0").tag_uri == "asdf://somewhere.org/extensions/full/tags/foo-1.0"
-    assert manager.get_tag_definition("asdf://somewhere.org/extensions/full/tags/baz-1.0").tag_uri == "asdf://somewhere.org/extensions/full/tags/baz-1.0"
+    assert (
+        manager.get_tag_definition("asdf://somewhere.org/extensions/full/tags/foo-1.0").tag_uri
+        == "asdf://somewhere.org/extensions/full/tags/foo-1.0"
+    )
+    assert (
+        manager.get_tag_definition("asdf://somewhere.org/extensions/full/tags/baz-1.0").tag_uri
+        == "asdf://somewhere.org/extensions/full/tags/baz-1.0"
+    )
     with pytest.raises(KeyError):
         manager.get_tag_definition("asdf://somewhere.org/extensions/full/tags/bar-1.0")
 
@@ -421,18 +422,39 @@ def test_get_cached_extension_manager():
 def test_tag_definition():
     tag_def = TagDefinition(
         "asdf://somewhere.org/extensions/foo/tags/foo-1.0",
-        schema_uri="asdf://somewhere.org/extensions/foo/schemas/foo-1.0",
+        schema_uris="asdf://somewhere.org/extensions/foo/schemas/foo-1.0",
         title="Some title",
         description="Some description",
     )
 
     assert tag_def.tag_uri == "asdf://somewhere.org/extensions/foo/tags/foo-1.0"
-    assert tag_def.schema_uri == "asdf://somewhere.org/extensions/foo/schemas/foo-1.0"
+    assert tag_def.schema_uris == ["asdf://somewhere.org/extensions/foo/schemas/foo-1.0"]
     assert tag_def.title == "Some title"
     assert tag_def.description == "Some description"
 
     assert "URI: asdf://somewhere.org/extensions/foo/tags/foo-1.0" in repr(tag_def)
 
+    with pytest.warns(AsdfDeprecationWarning):
+        assert tag_def.schema_uri == "asdf://somewhere.org/extensions/foo/schemas/foo-1.0"
+
+    tag_def = TagDefinition(
+        "asdf://somewhere.org/extensions/foo/tags/foo-1.0",
+        schema_uris=[
+            "asdf://somewhere.org/extensions/foo/schemas/foo-1.0",
+            "asdf://somewhere.org/extensions/foo/schemas/base-1.0",
+        ],
+        title="Some title",
+        description="Some description",
+    )
+
+    assert tag_def.schema_uris == [
+        "asdf://somewhere.org/extensions/foo/schemas/foo-1.0",
+        "asdf://somewhere.org/extensions/foo/schemas/base-1.0",
+    ]
+    with pytest.warns(AsdfDeprecationWarning):
+        with pytest.raises(RuntimeError):
+            tag_def.schema_uri
+
     with pytest.raises(ValueError):
         TagDefinition("asdf://somewhere.org/extensions/foo/tags/foo-*")
 
@@ -488,10 +510,7 @@ def test_converter_proxy():
     assert proxy != ConverterProxy(MinimumConverter(), extension)
     assert proxy != ConverterProxy(converter, MinimumExtension())
     assert proxy in {ConverterProxy(converter, extension)}
-    assert proxy not in {
-        ConverterProxy(MinimumConverter(), extension),
-        ConverterProxy(converter, MinimumExtension())
-    }
+    assert proxy not in {ConverterProxy(MinimumConverter(), extension), ConverterProxy(converter, MinimumExtension())}
 
     # Check the __repr__:
     assert "class: asdf.tests.test_extension.MinimumConverter" in repr(proxy)
@@ -503,22 +522,22 @@ def test_converter_proxy():
             "asdf://somewhere.org/extensions/test/tags/foo-*",
             "asdf://somewhere.org/extensions/test/tags/bar-*",
         ],
-        types=[FooType, BarType]
+        types=[FooType, BarType],
     )
 
     extension = FullExtension(
         tags=[
             TagDefinition(
                 "asdf://somewhere.org/extensions/test/tags/foo-1.0",
-                schema_uri="asdf://somewhere.org/extensions/test/schemas/foo-1.0",
+                schema_uris="asdf://somewhere.org/extensions/test/schemas/foo-1.0",
                 title="Foo tag title",
-                description="Foo tag description"
+                description="Foo tag description",
             ),
             TagDefinition(
                 "asdf://somewhere.org/extensions/test/tags/bar-1.0",
-                schema_uri="asdf://somewhere.org/extensions/test/schemas/bar-1.0",
+                schema_uris="asdf://somewhere.org/extensions/test/schemas/bar-1.0",
                 title="Bar tag title",
-                description="Bar tag description"
+                description="Bar tag description",
             ),
         ]
     )
@@ -620,22 +639,23 @@ tags:
                 pass
 
         converter = FooConverter()
+        compressor = MinimalCompressor()
 
         extension = ManifestExtension.from_uri(
             "asdf://somewhere.org/extensions/foo",
             legacy_class_names=["foo.extension.LegacyExtension"],
             converters=[converter],
-            compressors=[MinimalCompressor],
+            compressors=[compressor],
         )
         assert extension.extension_uri == "asdf://somewhere.org/extensions/foo"
         assert extension.legacy_class_names == ["foo.extension.LegacyExtension"]
         assert extension.asdf_standard_requirement == SpecifierSet(">=1.6.0,<2.0.0")
         assert extension.converters == [converter]
-        assert extension.compressors == [MinimalCompressor]
+        assert extension.compressors == [compressor]
         assert len(extension.tags) == 2
         assert extension.tags[0] == "asdf://somewhere.org/tags/bar"
         assert extension.tags[1].tag_uri == "asdf://somewhere.org/tags/baz"
-        assert extension.tags[1].schema_uri == "asdf://somewhere.org/schemas/baz"
+        assert extension.tags[1].schema_uris == ["asdf://somewhere.org/schemas/baz"]
         assert extension.tags[1].title == "Baz title"
         assert extension.tags[1].description == "Bar description"
 
@@ -644,11 +664,11 @@ tags:
         assert proxy.legacy_class_names == {"foo.extension.LegacyExtension"}
         assert proxy.asdf_standard_requirement == SpecifierSet(">=1.6.0,<2.0.0")
         assert proxy.converters == [ConverterProxy(converter, proxy)]
-        assert proxy.compressors == [MinimalCompressor]
+        assert proxy.compressors == [compressor]
         assert len(proxy.tags) == 2
         assert proxy.tags[0].tag_uri == "asdf://somewhere.org/tags/bar"
         assert proxy.tags[1].tag_uri == "asdf://somewhere.org/tags/baz"
-        assert proxy.tags[1].schema_uri == "asdf://somewhere.org/schemas/baz"
+        assert proxy.tags[1].schema_uris == ["asdf://somewhere.org/schemas/baz"]
         assert proxy.tags[1].title == "Baz title"
         assert proxy.tags[1].description == "Bar description"
 
